@@ -1,10 +1,11 @@
 import pylsl
-
+from .utils import suppress_stdout_stderr
 
 def show(args):
 	stream_name = args.name
-
-	infos = pylsl.resolve_streams(args.timeout)
+	
+	with suppress_stdout_stderr():
+		infos = pylsl.resolve_streams(args.timeout)
 	names = [i.name() for i in infos]
 
 	if stream_name not in names: 
@@ -12,6 +13,7 @@ def show(args):
 		return
 
 	stream_info = infos[names.index(stream_name)]
-	inlet = pylsl.StreamInlet(stream_info)
+	with suppress_stdout_stderr():
+		inlet = pylsl.StreamInlet(stream_info)
 
 	print(inlet.info().as_xml())
